package com.mopub.mobileads;

import androidx.annotation.NonNull;

import com.mopub.common.Preconditions;

import java.util.HashMap;
import java.util.Map;

public class AlxNativeAdViewBinder {

    int layoutId;
    int titleId;
    int textId;
    int callToActionId;
    int iconViewId;
    int mainImageViewId;
    int logoViewId;
    Map<String, Integer> extras;

    public AlxNativeAdViewBinder(Builder builder) {
        Preconditions.checkNotNull(builder);
        this.layoutId = builder.layoutId;
        this.titleId = builder.titleId;
        this.textId = builder.textId;
        this.callToActionId = builder.callToActionId;
        this.iconViewId = builder.iconViewId;
        this.mainImageViewId = builder.mainImageViewId;
        this.logoViewId = builder.logoViewId;
        this.extras = builder.extras;
    }

    public static class Builder {
        private int layoutId;
        private int titleId;
        private int textId;
        private int callToActionId;
        private int iconViewId;
        private int mainImageViewId;
        private int logoViewId;
        private Map<String, Integer> extras;

        public Builder(int layoutId) {
            this.layoutId = layoutId;
            this.extras = new HashMap<String, Integer>();
        }

        public Builder titleId(int viewId) {
            this.titleId = viewId;
            return this;
        }

        public Builder textId(int viewId) {
            this.textId = viewId;
            return this;
        }

        public Builder callToActionId(int viewId) {
            this.callToActionId = viewId;
            return this;
        }

        public Builder iconImageId(int viewId) {
            this.iconViewId = viewId;
            return this;
        }

        public Builder mainImageId(int viewId) {
            this.mainImageViewId = viewId;
            return this;
        }

        public Builder logoViewId(int viewId) {
            this.logoViewId = viewId;
            return this;
        }

        @NonNull
        public final Builder extras(final Map<String, Integer> resourceIds) {
            this.extras = new HashMap<String, Integer>(resourceIds);
            return this;
        }

        @NonNull
        public final Builder addExtra(final String key, final int resourceId) {
            this.extras.put(key, resourceId);
            return this;
        }

        public AlxNativeAdViewBinder build() {
            return new AlxNativeAdViewBinder(this);
        }
    }
}
