package com.alxad.alx.demo;

import android.annotation.SuppressLint;
import android.os.Bundle;
import android.util.Log;
import android.view.View;
import android.widget.TextView;
import android.widget.Toast;

import androidx.appcompat.app.AppCompatActivity;

import com.alxad.AppConfig;
import com.alxad.R;
import com.alxad.api.AlxInterstitialAD;
import com.alxad.api.AlxInterstitialADListener;

public class AlxInterstitialDemoActivity extends AppCompatActivity implements View.OnClickListener {
    private static final String TAG = "AlxInterstitial";

    private TextView mTvTip;
    private TextView mTvVideoShow;
    private AlxInterstitialAD mInterstitialAD;
    private long startTime;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_alx_interstitial_demo);
        initView();
    }

    private void initView() {
        TextView tv_video_load = findViewById(R.id.tv_video_load);
        mTvVideoShow = findViewById(R.id.tv_video_show);
        mTvTip = findViewById(R.id.tv_tip);
        mTvVideoShow.setEnabled(false);
        tv_video_load.setOnClickListener(this);
        mTvVideoShow.setOnClickListener(this);
        mInterstitialAD = new AlxInterstitialAD();
    }

    @SuppressLint("NonConstantResourceId")
    @Override
    public void onClick(View v) {
        switch (v.getId()) {
            case R.id.tv_video_load:
                loAd();
                break;
            case R.id.tv_video_show:
                if (mInterstitialAD.isReady()) {
                    mInterstitialAD.show(this);
                } else {
                    loAd();
                }
                break;
        }
    }

    /**
     * 加载广告
     */
    public void loAd() {
        mTvTip.setText("广告加载中...");
        startTime = System.currentTimeMillis();
        mInterstitialAD.load(this, AppConfig.ALX_INTERSTITIAL_AD_PID, new AlxInterstitialADListener() {

            @Override
            public void onInterstitialAdLoaded() {
                Log.i(TAG, "onInterstitialAdLoaded: "+getThreadName());
                runOnUiThread(new Runnable() {
                    @Override
                    public void run() {
                        Toast.makeText(getBaseContext(), "插屏广告加载成功", Toast.LENGTH_SHORT).show();
                        mTvTip.setText("广告加载成功--耗时-" + (System.currentTimeMillis() - startTime) / 1000 + "-秒");
                        mTvVideoShow.setEnabled(true);
                    }
                });
            }

            @Override
            public void onInterstitialAdLoadFail(int errorCode, String errorMsg) {
                Log.i(TAG, "onInterstitialAdLoadFail: "+getThreadName() +" "+ errorCode + " " + errorMsg);
                runOnUiThread(new Runnable() {
                    @Override
                    public void run() {
                        Toast.makeText(getBaseContext(), "插屏广告加载失败", Toast.LENGTH_SHORT).show();
                        mTvTip.setText("广告加载错误");
                        mTvVideoShow.setEnabled(false);
                    }
                });
            }

            @Override
            public void onInterstitialAdClicked() {
                Log.i(TAG, "onInterstitialAdClicked: "+getThreadName());
                runOnUiThread(new Runnable() {
                    @Override
                    public void run() {
                        Toast.makeText(getBaseContext(), "插屏广告点击成功", Toast.LENGTH_SHORT).show();

                    }
                });
            }

            @Override
            public void onInterstitialAdShow() {
                Log.i(TAG, "onInterstitialAdShow: "+getThreadName());
            }

            @Override
            public void onInterstitialAdClose() {
                Log.i(TAG, "onInterstitialAdClose: "+getThreadName());
                runOnUiThread(new Runnable() {
                    @Override
                    public void run() {
                        mTvVideoShow.setEnabled(false);
                        mTvTip.setText("广告未加载");
                    }
                });
            }

            @Override
            public void onInterstitialAdVideoStart() {
                Log.i(TAG, "onInterstitialAdVideoStart: "+getThreadName());
                runOnUiThread(new Runnable() {
                    @Override
                    public void run() {
                        Toast.makeText(getBaseContext(), "插屏广告展示成功", Toast.LENGTH_SHORT).show();
                    }
                });
            }

            @Override
            public void onInterstitialAdVideoEnd() {
                Log.i(TAG, "onInterstitialAdVideoEnd-插屏广告观看完整: "+getThreadName());
                runOnUiThread(new Runnable() {
                    @Override
                    public void run() {
                        Toast.makeText(getBaseContext(), "插屏广告观看完整", Toast.LENGTH_SHORT).show();
                    }
                });
            }

            @Override
            public void onInterstitialAdVideoError(int errorCode,String errorMsg) {
                Log.i(TAG, "onInterstitialAdVideoError-视频播放失败: "+getThreadName()+" "+errorCode+","+errorMsg);
            }
           
        });

    }

    private String getThreadName(){
        return Thread.currentThread().getName();
    }
}