package com.alxad.alx.demo;


import android.content.Context;
import android.content.Intent;
import android.os.Bundle;
import android.util.DisplayMetrics;
import android.util.Log;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.Button;
import android.widget.FrameLayout;
import android.widget.ImageView;
import android.widget.TextView;

import androidx.appcompat.app.AppCompatActivity;

import com.alxad.AppConfig;
import com.alxad.R;
import com.alxad.api.AlxNativeAD;
import com.alxad.api.AlxNativeAdListener;
import com.alxad.api.AlxNativeAdLoadListener;
import com.alxad.api.AlxNativeExpressAdListener;
import com.alxad.api.IAlxNativeInfo;
import com.bumptech.glide.Glide;

import java.util.ArrayList;
import java.util.List;

/**
 * 原生广告——在其他容器 中显示
 */
public class AlxNativeOtherActivity extends AppCompatActivity {
    private final String TAG = "AlxNativeOtherDemo";

    private int mAdStyleType;
    private FrameLayout mAdContainer;
    private AlxNativeAD mNativeAd;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_alx_native_other);
        initView();
        initData();
        loadAd();
    }

    private void initView() {
        mAdContainer = (FrameLayout) findViewById(R.id.ad_container);
    }

    private void initData() {
        Intent intent = getIntent();
        boolean value = intent.getBooleanExtra(AlxNativeDemoActivity.EXTRA_AD_TYPE, true);
        if (value) {
            mAdStyleType = AlxNativeAD.AlxAdSlot.TYPE_EXPRESS_AD;
        } else {
            mAdStyleType = AlxNativeAD.AlxAdSlot.TYPE_NATIVE_AD;
        }
    }

    private void loadAd() {
        //初始化广告位。仅调用一次。
        mNativeAd = new AlxNativeAD(this, AppConfig.ALX_NATIVE_AD_PID);
        AlxNativeAD.AlxAdSlot adSlot = new AlxNativeAD.AlxAdSlot()
                .setAdStyleType(mAdStyleType);// **必传，表示请求的模板广告还是原生广告，AdSlot.TYPE_EXPRESS_AD：模板广告 ； AdSlot.TYPE_NATIVE_AD：原生广告**
        mNativeAd.load(adSlot, new AlxNativeAdLoadListener() {
            @Override
            public void onAdLoadedFail(int errorCode, String errorMsg) {
                Log.i(TAG, "onAdLoadedFail:" + getThreadName() + " " + errorCode + ";" + errorMsg);
            }

            @Override
            public void onAdLoaded(final List<IAlxNativeInfo> ads) {
                Log.i(TAG, "onAdLoaded:" + getThreadName());

                if (ads == null || ads.isEmpty()) {
                    return;
                }
                IAlxNativeInfo bean = ads.get(0);
                if (bean.isExpressAd()) {
                    renderExpressViewAd(bean);
                } else {
                    renderNativeViewAd(bean);
                }
            }
        });
    }

    @Override
    protected void onDestroy() {
        super.onDestroy();
        if (mNativeAd != null) {
            mNativeAd.destroy();
        }
    }


    /**
     * 模版广告
     *
     * @return
     */
    private void renderExpressViewAd(final IAlxNativeInfo bean) {
        bean.setAlxNativeAdListener(new AlxNativeExpressAdListener() {
            @Override
            public void onAdClose() {
                Log.i(TAG, "onAdClose:" + getThreadName());
                bean.destroy();
                mAdContainer.removeAllViews();
            }

            @Override
            public void onRenderFail(int code, String msg) {
                Log.i(TAG, "onRenderFail:" + getThreadName() + "::" + code + ";" + msg);
            }

            @Override
            public void onRenderSuccess(View view) {
                Log.i(TAG, "onRenderSuccess:" + getThreadName());
            }

            @Override
            public void onAdClick() {
                Log.i(TAG, "onAdClicked:" + getThreadName());
            }

            @Override
            public void onAdShow() {
                Log.i(TAG, "onAdShow:" + getThreadName());
            }
        });
        View expressView = bean.getExpressView();
        if (expressView != null) {
            mAdContainer.removeAllViews();
            mAdContainer.addView(expressView);
            bean.render();
        }
    }

    /**
     * 自渲染广告
     *
     * @return
     */
    private void renderNativeViewAd(final IAlxNativeInfo bean) {
        View convertView = LayoutInflater.from(this).inflate(R.layout.adapter_native_big_img, null);
        ImageView mIvLogo = (ImageView) convertView.findViewById(R.id.iv_logo);
        ImageView mIvIcon = (ImageView) convertView.findViewById(R.id.iv_ad_icon);
        TextView mTitle = (TextView) convertView.findViewById(R.id.tv_ad_title);
        TextView mDescription = (TextView) convertView.findViewById(R.id.tv_ad_desc);
        Button mSource = (Button) convertView.findViewById(R.id.adapter_ad_source);
        ImageView mClose = (ImageView) convertView.findViewById(R.id.adapter_ad_close);
        ImageView mBigImg = (ImageView) convertView.findViewById(R.id.iv_image);

        mAdContainer.addView(convertView);

        mIvLogo.setImageBitmap(bean.getAdLogo());
        mTitle.setText(bean.getTitle());
        mDescription.setText(bean.getDescription());
        mSource.setText(bean.getInteractionText());
        Glide.with(this).load(bean.getImageUrl()).into(mBigImg);
        Glide.with(this).load(bean.getIconUrl()).into(mIvIcon);

        bean.setAlxNativeAdListener(new AlxNativeAdListener() {
            @Override
            public void onAdClick() {
                Log.i(TAG, "onAdClick:" + getThreadName());
            }

            @Override
            public void onAdShow() {
                Log.i(TAG, "onAdShow:" + getThreadName());
            }

            @Override
            public void onAdClose() {
                Log.i(TAG, "onAdClose:" + getThreadName());
                bean.destroy();
                mAdContainer.removeAllViews();
            }
        });

        List<View> clickView = new ArrayList<>();
        clickView.add(mBigImg);
        clickView.add(mTitle);
        clickView.add(mSource);
        bean.registerViewForInteraction((ViewGroup) convertView, clickView);
        bean.setCloseView(mClose);
    }

    private String getThreadName() {
        return Thread.currentThread().getName();
    }


    /**
     * 获取屏幕宽度
     *
     * @param context 上下文
     * @return 屏幕宽度
     */
    public static int getScreenWidth(Context context) {
        DisplayMetrics dm = context.getResources().getDisplayMetrics();
        return dm.widthPixels;
    }

}