package com.alxad.alx.demo;


import android.content.Context;
import android.content.Intent;
import android.os.Bundle;
import android.util.DisplayMetrics;
import android.util.Log;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.Button;
import android.widget.FrameLayout;
import android.widget.ImageView;
import android.widget.TextView;

import androidx.annotation.NonNull;
import androidx.appcompat.app.AppCompatActivity;
import androidx.recyclerview.widget.DividerItemDecoration;
import androidx.recyclerview.widget.LinearLayoutManager;
import androidx.recyclerview.widget.RecyclerView;

import com.alxad.AppConfig;
import com.alxad.R;
import com.alxad.api.AlxNativeAD;
import com.alxad.api.AlxNativeAdListener;
import com.alxad.api.AlxNativeAdLoadListener;
import com.alxad.api.AlxNativeExpressAdListener;
import com.alxad.api.IAlxNativeInfo;
import com.bumptech.glide.Glide;


import java.util.ArrayList;
import java.util.List;

/**
 * 原生广告——在RecyclerView中显示
 */
public class AlxNativeRecyclerViewActivity extends AppCompatActivity {
    private final String TAG = "AlxNativeRecyclerDemo";

    private MyAdapter mAdapter;
    private int mAdStyleType;
    private AlxNativeAD mNativeAd;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_alx_native_recyclerview);
        initView();
        initData();
        loadAd();
    }

    private void initView() {
        RecyclerView mRecyclerView = (RecyclerView) findViewById(R.id.recycler_view);
        mRecyclerView.setLayoutManager(new LinearLayoutManager(this, LinearLayoutManager.VERTICAL, false));
        DividerItemDecoration dividerItem = new DividerItemDecoration(this, DividerItemDecoration.VERTICAL);
        dividerItem.setDrawable(getResources().getDrawable(R.drawable.divider_white));
        mRecyclerView.addItemDecoration(dividerItem);

        mAdapter = new MyAdapter(this);
        mRecyclerView.setAdapter(mAdapter);
    }

    private void initData() {
        Intent intent = getIntent();
        boolean value = intent.getBooleanExtra(AlxNativeDemoActivity.EXTRA_AD_TYPE, true);
        if (value) {
            mAdStyleType = AlxNativeAD.AlxAdSlot.TYPE_EXPRESS_AD;
        } else {
            mAdStyleType = AlxNativeAD.AlxAdSlot.TYPE_NATIVE_AD;
        }
    }


    private void loadAd() {
        //初始化广告位。仅调用一次。
        mNativeAd = new AlxNativeAD(this, AppConfig.ALX_NATIVE_AD_PID);
        AlxNativeAD.AlxAdSlot adSlot = new AlxNativeAD.AlxAdSlot()
                .setAdStyleType(mAdStyleType);// **必传，表示请求的模板广告还是原生广告，AdSlot.TYPE_EXPRESS_AD：模板广告 ； AdSlot.TYPE_NATIVE_AD：原生广告**
        mNativeAd.load(adSlot, new AlxNativeAdLoadListener() {
            @Override
            public void onAdLoadedFail(int errorCode, String errorMsg) {
                Log.i(TAG, "onAdLoadedFail:" + getThreadName() + " " + errorCode + ";" + errorMsg);
            }

            @Override
            public void onAdLoaded(final List<IAlxNativeInfo> ads) {
                Log.i(TAG, "onAdLoaded:" + getThreadName());

                if (ads == null) {
                    return;
                }
                List<IAlxNativeInfo> list = new ArrayList<>();
                for (IAlxNativeInfo item : ads) {
                    for (int i = 0; i < 5; i++) {
                        list.add(null);
                    }
                    list.add(item);
                }
                for (int i = 0; i < 12; i++) {
                    list.add(null);
                }
                mAdapter.setRefreshData(list);
            }
        });
    }

    @Override
    protected void onDestroy() {
        super.onDestroy();
        if (mNativeAd != null) {
            mNativeAd.destroy();
        }
    }

    private String getThreadName() {
        return Thread.currentThread().getName();
    }

    private class MyAdapter extends RecyclerView.Adapter<RecyclerView.ViewHolder> {

        private static final int ITEM_VIEW_TYPE_NORMAL = 0;
        private static final int ITEM_VIEW_TYPE_NATIVE_AD = 1;
        private static final int ITEM_VIEW_TYPE_EXPRESS_AD = 2;

        private Context mContext;
        private List<IAlxNativeInfo> mList;

        public MyAdapter(Context context) {
            mContext = context;
        }

        public void setRefreshData(List<IAlxNativeInfo> list) {
            if (list == null) {
                if (mList == null) {
                    mList = new ArrayList<>();
                } else {
                    mList.clear();
                }
                notifyDataSetChanged();
                return;
            }
            if (mList == null) {
                mList = new ArrayList<>();
            }
            mList.clear();
            mList.addAll(list);
            notifyDataSetChanged();
        }

        @Override
        public long getItemId(int position) {
            return position;
        }


        @Override
        public int getItemCount() {
            return (mList == null || mList.isEmpty()) ? 0 : mList.size();
        }

        @NonNull
        @Override
        public RecyclerView.ViewHolder onCreateViewHolder(@NonNull ViewGroup parent, int viewType) {
            View view;
            switch (viewType) {
                case ITEM_VIEW_TYPE_NATIVE_AD:
                    view = LayoutInflater.from(mContext).inflate(R.layout.adapter_native_big_img, parent, false);
                    return new AdBigViewHolder(view);
                case ITEM_VIEW_TYPE_EXPRESS_AD:
                    view = LayoutInflater.from(mContext).inflate(R.layout.adapter_native_express, parent, false);
                    return new AdExpressViewHolder(view);
                default:
                    view = LayoutInflater.from(mContext).inflate(R.layout.adapter_native_normal, parent, false);
                    return new NormalViewHolder(view);
            }
        }

        @Override
        public void onBindViewHolder(@NonNull RecyclerView.ViewHolder holder, int position) {
            int viewType=getItemViewType(position);
            switch (viewType){
                case ITEM_VIEW_TYPE_EXPRESS_AD:
                    if (holder instanceof AdExpressViewHolder) {
                        getExpressViewAd((AdExpressViewHolder) holder, position);
                    }
                    break;
                case ITEM_VIEW_TYPE_NATIVE_AD:
                    if (holder instanceof AdBigViewHolder) {
                        getBigImgViewAd((AdBigViewHolder) holder, position);
                    }
                    break;
                case ITEM_VIEW_TYPE_NORMAL:
                default:
                    if (holder instanceof NormalViewHolder) {
                        getNormalView((NormalViewHolder) holder, position);
                    }
            }
        }

        @Override
        public int getItemViewType(int position) {
            IAlxNativeInfo bean = mList.get(position);
            if (bean == null) {
                return ITEM_VIEW_TYPE_NORMAL;
            }
            if (bean.isExpressAd()) {
                return ITEM_VIEW_TYPE_EXPRESS_AD;
            } else {
                return ITEM_VIEW_TYPE_NATIVE_AD;
            }
        }

        /**
         * 自渲染广告
         *
         * @param holder
         * @param position
         * @return
         */
        private void getBigImgViewAd(AdBigViewHolder holder, int position) {
            final IAlxNativeInfo bean = mList.get(position);
            holder.mIvLogo.setImageBitmap(bean.getAdLogo());
            holder.mTitle.setText(bean.getTitle());
            holder.mDescription.setText(bean.getDescription());
            holder.mSource.setText(bean.getInteractionText());
            Glide.with(mContext).load(bean.getImageUrl()).into(holder.mBigImg);
            Glide.with(mContext).load(bean.getIconUrl()).into(holder.mIvIcon);

            bean.setAlxNativeAdListener(new AlxNativeAdListener() {
                @Override
                public void onAdClick() {
                    Log.i(TAG, "onAdClick:" + getThreadName());
                }

                @Override
                public void onAdShow() {
                    Log.i(TAG, "onAdShow:" + getThreadName());
                }

                @Override
                public void onAdClose() {
                    Log.i(TAG, "onAdClose:" + getThreadName());
                    bean.destroy();
                    mList.remove(bean);
                    notifyDataSetChanged();
                }
            });

            List<View> clickView = new ArrayList<>();
            clickView.add(holder.mBigImg);
            clickView.add(holder.mTitle);
            clickView.add(holder.mSource);
            bean.registerViewForInteraction((ViewGroup) holder.itemView, clickView);
            bean.setCloseView(holder.mClose);

//            holder.mClose.setOnClickListener(new View.OnClickListener() {
//                @Override
//                public void onClick(View v) {
//                    mList.remove(bean);
//                    notifyDataSetChanged();
//                }
//            });
        }

        /**
         * 模版广告
         *
         * @param holder
         * @param position
         * @return
         */
        private void getExpressViewAd(final AdExpressViewHolder holder, final int position) {
            final IAlxNativeInfo bean = mList.get(position);
            bean.setAlxNativeAdListener(new AlxNativeExpressAdListener() {
                @Override
                public void onAdClose() {
                    Log.i(TAG, "onAdClose:" + getThreadName());
                    bean.destroy();
                    mList.remove(bean);
                    notifyDataSetChanged();
                }

                @Override
                public void onRenderFail(int code, String msg) {
                    Log.i(TAG, "onRenderFail:" + getThreadName() + "::" + code + ";" + msg);
                }

                @Override
                public void onRenderSuccess(View view) {
                    Log.i(TAG, "onRenderSuccess:" + getThreadName());
                }

                @Override
                public void onAdClick() {
                    Log.i(TAG, "onAdClicked:" + getThreadName());
                }

                @Override
                public void onAdShow() {
                    Log.i(TAG, "onAdShow:" + getThreadName());
                }
            });
            View expressView = bean.getExpressView();
            if (holder.mAdContainerView != null && expressView!=null) {
                if(expressView.getParent()!=null){
                    if(expressView.getParent() instanceof ViewGroup) {
                        ViewGroup groupView = (ViewGroup) expressView.getParent();
                        groupView.removeAllViews();
                    }
                }
                if(expressView.getParent()==null){
                    holder.mAdContainerView.removeAllViews();
                    FrameLayout.LayoutParams layoutParams = new FrameLayout.LayoutParams(ViewGroup.LayoutParams.MATCH_PARENT, ViewGroup.LayoutParams.WRAP_CONTENT);
                    holder.mAdContainerView.addView(expressView,layoutParams);

                }
                bean.render();
            }
        }

        private void getNormalView(NormalViewHolder holder, int position) {
            holder.mTvTitle.setText("信息流测试标题广告-RecyclerView:  " + position);
            holder.mTvDesc.setText("信息流测试描述广告-RecyclerView:  " + position);
        }
    }

    public static abstract class AdViewHolder extends RecyclerView.ViewHolder {
        ImageView mIvLogo;
        ImageView mIvIcon;
        TextView mTitle;
        TextView mDescription;
        Button mSource;
        ImageView mClose;

        public AdViewHolder(@NonNull View itemView) {
            super(itemView);
        }
    }

    private static class AdBigViewHolder extends AdViewHolder {
        ImageView mBigImg;

        public AdBigViewHolder(@NonNull View itemView) {
            super(itemView);
            mIvLogo = (ImageView) itemView.findViewById(R.id.iv_logo);
            mIvIcon = (ImageView) itemView.findViewById(R.id.iv_ad_icon);
            mTitle = (TextView) itemView.findViewById(R.id.tv_ad_title);
            mDescription = (TextView) itemView.findViewById(R.id.tv_ad_desc);
            mSource = (Button) itemView.findViewById(R.id.adapter_ad_source);
            mClose = (ImageView) itemView.findViewById(R.id.adapter_ad_close);
            mBigImg = (ImageView) itemView.findViewById(R.id.iv_image);
        }
    }

    private static class AdExpressViewHolder extends AdViewHolder {
        FrameLayout mAdContainerView;

        public AdExpressViewHolder(View itemView) {
            super(itemView);
            mAdContainerView = (FrameLayout) itemView.findViewById(R.id.item_express);
        }
    }

    private static class NormalViewHolder extends RecyclerView.ViewHolder {
        ImageView mIvIcon;
        TextView mTvTitle;
        TextView mTvDesc;

        public NormalViewHolder(@NonNull View itemView) {
            super(itemView);
            mIvIcon = (ImageView) itemView.findViewById(R.id.item_icon);
            mTvTitle = (TextView) itemView.findViewById(R.id.item_title);
            mTvDesc = (TextView) itemView.findViewById(R.id.item_desc);
        }
    }


    /**
     * 获取屏幕宽度
     *
     * @param context 上下文
     * @return 屏幕宽度
     */
    public static int getScreenWidth(Context context) {
        DisplayMetrics dm = context.getResources().getDisplayMetrics();
        return dm.widthPixels;
    }


}